terraform {
  required_providers {
    proxmox = {
      source = "telmate/proxmox"
      version = "3.0.1-rc3"
    }
  }
}

provider "proxmox" {
  pm_api_url = "https://medico.ucc.asn.au:8006/api2/json"
  pm_log_enable = true
}

locals {
  config = yamldecode(file("membervm_nogui.yml"))
}

resource "proxmox_vm_qemu" "membervm_nogui" {
  for_each = local.config

  # Per-VM settings
  name = each.key
  desc = each.value.desc

  target_node = each.value.node

  sockets = each.value.sockets
  cores = each.value.cores
  memory = each.value.memory

  ciuser = each.value.primary_user
  sshkeys = each.value.primary_sshkey

  vm_state = each.value.state

  # Set the template, then all remaining settings must match those for that template
  clone = "memberVM-nogui-template"

  agent = 1
  cpu = "x86-64-v2-AES"
  scsihw = "virtio-scsi-pci"
  boot = "order=scsi0"
  ipconfig0 = "ip=dhcp,ip6=auto"

  disks {
    scsi {
      scsi0 {
        disk {
          storage = "vmstore-ssd"
          size = each.value.disk # This can be increased, but must be >= the size of the template image
        }
      }
    }
    ide {
      ide2 {
        cloudinit {
          storage = "vmstore-ssd"
        }
      }
    }
  }

  network {
    bridge = "vmbr0"
    model = "virtio"
    tag = 4
  }

  # Always the same, regardless of the template chosen
  os_type = "cloud-init"
  pool = "Member-VMs-Auto"

  agent_timeout = 120 # VM creation takes longer than the default of 60s
}
